@@ -13,8 +13,11 @@ print "Determining OS (in determine_os())\n" if $verbose;
     "FREEBSD3", "FreeBSD.3",
     "FREEBSD4", "FreeBSD.4",
     "FREEBSD5", "FreeBSD.5",
+    "FREEBSD6", "FreeBSD.6",
+    "FREEBSD7", "FreeBSD.7",
     "OPENBSD2", "OpenBSD.2",
     "OPENBSD3", "OpenBSD.3",
+    "OPENBSD4", "OpenBSD.4",
     "BSDI2", "BSD\/OS.2",
     "BSDI3", "BSD\/OS.3",
     "BSDI4", "BSD\/OS.4",
