@@ -182,10 +182,16 @@ static void print_inode(INUM_T inum, FS_INODE *fs_inode, int flags,
 #ifdef HAVE_DTIME
     printf("|%lu", (ULONG) fs_inode->dtime);
 #endif
-    printf("|%lo|%d|%lu|%lu|%lu\n",
-	   (ULONG) fs_inode->mode, (int) fs_inode->nlink,
-	   (ULONG) fs_inode->size, (ULONG) fs_inode->direct_addr[0],
-	   (ULONG) fs_inode->direct_addr[1]);
+    if (sizeof(fs_inode->size) <= sizeof(unsigned long))
+	printf("|%lo|%d|%lu|%lu|%lu\n",
+	       (ULONG) fs_inode->mode, (int) fs_inode->nlink,
+	       (ULONG) fs_inode->size, (ULONG) fs_inode->direct_addr[0],
+	       (ULONG) fs_inode->direct_addr[1]);
+    else
+	printf("|%lo|%d|%llu|%lu|%lu\n",
+	       (ULONG) fs_inode->mode, (int) fs_inode->nlink,
+	       (unsigned long long) fs_inode->size, (ULONG) fs_inode->direct_addr[0],
+	       (ULONG) fs_inode->direct_addr[1]);
 }
 
 /* main - open file system, list inode info */
