@@ -23,7 +23,8 @@
 #ifdef USE_MYLSEEK
 #ifdef HAVE_LLSEEK
 #include <errno.h>
-#include <syscall.h>
+#include <unistd.h>
+#include <linux/unistd.h>
 
  /*
   * This is LINUX, live on the bleeding edge and watch your software break
