@@ -22,14 +22,19 @@
 /* DIAGNOSTICS
 /*	The command exit status is the exit status of the command
 /*	(status 1 in case of a usage error).
+/* LICENSE
+/*	The IBM PUBLIC LICENSE must be distributed with this
+/*	software.
+/* HISTORY
+/*	This program was first released as part of SATAN.
 /* AUTHOR(S)
 /*	Wietse Venema
-/*	This program is part of SATAN.
 /*--*/
 
 /* System libraries. */
 
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -103,6 +108,6 @@ char  **argv;
 	alarm(time_to_run);
 	while ((pid = wait(&status)) != -1 && pid != child_pid)
 	     /* void */ ;
-	return (pid == child_pid ? status : -1);
+	return (pid == child_pid ? WEXITSTATUS(status) | WTERMSIG(status) : -1);
     }
 }
