@@ -115,7 +115,7 @@
   * grope kernel memory instead.
   */
 #if defined(FREEBSD2) || defined(FREEBSD3) || defined(FREEBSD4) \
-	|| defined(FREEBSD5)
+	|| defined(FREEBSD5) || defined(FREEBSD6) || defined(FREEBSD7)
 #define SUPPORTED
 #include <sys/param.h>
 #include <sys/user.h>
@@ -136,7 +136,7 @@
 #define PROCP_VMSPACE(p) ((p)->kp_proc.p_vmspace)
 #endif
 
-#if defined(FREEBSD5)
+#if defined(FREEBSD5) || defined(FREEBSD6) || defined(FREEBSD7)
 #define PROCP_STATUS(p) ((p)->ki_stat)
 #define PROCP_VMSPACE(p) ((p)->ki_vmspace)
 #endif
@@ -193,7 +193,7 @@
   * OpenBSD 2.4 ptrace() resumes a stopped process when detaching, so we must
   * re-suspend upon detach.
   */
-#if defined(OPENBSD2) || defined(OPENBSD3)
+#if defined(OPENBSD2) || defined(OPENBSD3) || defined(OPENBSD4)
 #define SUPPORTED
 #include <sys/param.h>
 #include <sys/user.h>
@@ -571,7 +571,7 @@ static void copy_process(PROC_INFO *proc, int out_fd)
 static PROC_INFO *open_process(pid_t pid)
 {
 #if defined(FREEBSD2) || defined(FREEBSD3) || defined(FREEBSD4) \
-	|| defined(FREEBSD5)
+	|| defined(FREEBSD5) || defined(FREEBSD6) || defined(FREEBSD7)
     PROC_INFO *proc = (PROC_INFO *) mymalloc(sizeof(*proc));
     MAP_INFO *mp;
     struct kinfo_proc *procp;
@@ -918,7 +918,7 @@ static PROC_INFO *open_process(pid_t pid)
     return (proc);
 #endif
 
-#if defined(OPENBSD2) || defined(OPENBSD3)
+#if defined(OPENBSD2) || defined(OPENBSD3) || defined(OPENBSD4)
     PROC_INFO *proc;
     MAP_INFO *mp;
     struct kinfo_proc *procp;
